==> smallrye-open-api-core-3.0.0-sources.jar: io/smallrye/openapi/runtime/scanner/spi/ScannerSPILogging_$logger.java <==
package io.smallrye.openapi.runtime.scanner.spi;

import java.util.Locale;
import java.io.Serializable;
import java.lang.String;
import org.jboss.logging.Logger;


import static org.jboss.logging.Logger.Level.WARN;

/**
 * Warning this class consists of generated code.
 */
public class ScannerSPILogging_$logger implements ScannerSPILogging, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = ScannerSPILogging_$logger.class.getName();
    public ScannerSPILogging_$logger(final Logger log) {
        this.log = log;
    }
    protected final Logger log;
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void invalidDefault(final String segment, final String primitive) {
        log.logf(FQCN, WARN, null, invalidDefault$str(), segment, primitive);
    }
    protected String invalidDefault$str() {
        return "SROAP07900: Value '%s' is not a valid %s default";
    }
    @Override
    public final void missingPathSegment(final String segment) {
        log.logf(FQCN, WARN, null, missingPathSegment$str(), segment);
    }
    protected String missingPathSegment$str() {
        return "SROAP07901: Matrix parameter references missing path segment: %s";
    }
    @Override
    public final void missingFrameworkParam(final String frameworkName, final String className, final String method, final String paramName, final String paramIn) {
        log.logf(FQCN, WARN, null, missingFrameworkParam$str(), frameworkName, className, method, paramName, paramIn);
    }
    protected String missingFrameworkParam$str() {
        return "SROAP07902: @Parameter annotation missing %s parameter. Class: %s, Method: %s, Parameter.name: %s, Parameter.in: %s";
    }
}

==> smallrye-open-api-core-3.3.2-sources.jar: io/smallrye/openapi/runtime/scanner/spi/ScannerSPILogging_$logger.java <==
package io.smallrye.openapi.runtime.scanner.spi;

import java.util.Locale;
import java.io.Serializable;
import java.lang.String;
import org.jboss.logging.Logger;


import static org.jboss.logging.Logger.Level.WARN;

/**
 * Warning this class consists of generated code.
 */
public class ScannerSPILogging_$logger implements ScannerSPILogging, Serializable {
    private static final long serialVersionUID = 1L;
    private static final String FQCN = ScannerSPILogging_$logger.class.getName();
    public ScannerSPILogging_$logger(final Logger log) {
        this.log = log;
    }
    protected final Logger log;
    private static final Locale LOCALE = Locale.ROOT;
    protected Locale getLoggingLocale() {
        return LOCALE;
    }
    @Override
    public final void invalidDefault(final String segment, final String primitive) {
        log.logf(FQCN, WARN, null, invalidDefault$str(), segment, primitive);
    }
    protected String invalidDefault$str() {
        return "SROAP07900: Value '%s' is not a valid %s default";
    }
    @Override
    public final void missingPathSegment(final String segment) {
        log.logf(FQCN, WARN, null, missingPathSegment$str(), segment);
    }
    protected String missingPathSegment$str() {
        return "SROAP07901: Matrix parameter references missing path segment: %s";
    }
    @Override
    public final void missingFrameworkParam(final String frameworkName, final String className, final String method, final String paramName, final String paramIn) {
        log.logf(FQCN, WARN, null, missingFrameworkParam$str(), frameworkName, className, method, paramName, paramIn);
    }
    protected String missingFrameworkParam$str() {
        return "SROAP07902: @Parameter annotation missing %s parameter. Class: %s, Method: %s, Parameter.name: %s, Parameter.in: %s";
    }
    @Override
    public final void duplicateOperationId(final String operationId, final String className, final String method, final String conflictingClassName, final String conflictingMethod) {
        log.logf(FQCN, WARN, null, duplicateOperationId$str(), operationId, className, method, conflictingClassName, conflictingMethod);
    }
    protected String duplicateOperationId$str() {
        return "SROAP07903: Duplicate operationId: %s produced by Class: %s, Method: %s and Class: %s, Method: %s";
    }
}
